@@ -22,7 +22,7 @@ from collections.abc import Mapping
 from collections.abc import MutableMapping
 
 
-__version__: str = '1.27.1'
+__version__: str = '1.27.3'
 
 from typing import List, Dict, Any, Optional, Sequence, Union, Callable, Set, \
     Iterator, TYPE_CHECKING, Tuple
@@ -787,7 +787,8 @@ class DecoratorAPI(object):
             registration_kwargs={'event_pattern': event_pattern}
         )
 
-    def schedule(self, expression: str, name: Optional[str] = None,
+    def schedule(self, expression: Union[str, 'ScheduleExpression'],
+                 name: Optional[str] = None,
                  description: str = '') -> Callable[..., Any]:
         return self._create_registration_function(
             handler_type='schedule',
